---
template: mainpanel
source_form: markdown
name: Trello Cardlist Backlog: Tasks
updated: October 2016
title: Trello Cardlist Backlog: Tasks
---
### Backlog: Tasks

* 52\. Review whether context should check types of ALL expressions, rather than just first, and whether we can should try to detect type mismatches #reflect
* 53\. Use https://travis-ci.org/ ? #reflect
* 54\. Review pypi packaging for things we should be doing #reflect #practicalities
* 55\. Create pyxie-service for managing batch compilation services #practicalities
